@@ -46,10 +46,11 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.61'; # VERSION
+our $VERSION = '1.63'; # VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
+    CurrencyFreaks
     ECB
     Fixer
     OpenExchange
@@ -63,6 +64,7 @@ our $VERSION = '1.61'; # VERSION
     AlphaVantage
     BSEIndia
     Bloomberg
+    BorsaItaliana
     Bourso
     BVB
     CSE
@@ -71,9 +73,11 @@ our $VERSION = '1.61'; # VERSION
     Currencies
     DWS
     Deka
-    FTfunds
+    FinanceAPI
     Finanzpartner
     Fondsweb
+    Fool
+    FTfunds
     GoldMoney
     GoogleWeb
     HU
@@ -91,6 +95,7 @@ our $VERSION = '1.61'; # VERSION
     SEB
     SIX
     Sinvestor
+    StockData
     Stooq
     TesouroDireto
     Tiaacref
@@ -1334,8 +1339,8 @@ conversion method or configure fallback methods, include the 'order' key, which
 points to an array of Finance::Quote::CurrencyRates module names.
 Setting the environment variable FQ_CURRENCY will change the default 
 endpoint used for currency conversion.
-See the documentation for the individual Finance::Quote::CurrencyRates to
-learn more. 
+See the documentation for the individual Finance::Quote::CurrencyRates
+modules to learn more. 
 
 =head2 get_default_currency_fields
 
@@ -1391,8 +1396,11 @@ modules are used is controlled by the argument
 
     currency_rates => {order => [subset of $features{currency_modules}]} 
 
-to Finance::Quote->new().  By default, only AlphaVantage in used for 
-currency conversion, so "order" must be set to use other currency modules.
+to Finance::Quote->new().  By default, AlphaVantage in used for 
+currency conversion, "order" can be set to use other currency modules.
+The currency module used can also be changed by setting the FQ_CURRENCY
+environment variable. Please note that some of the alternate currency
+modules require API keys.
 
 
 =head1 PUBLIC OBJECT METHODS
@@ -1539,8 +1547,8 @@ second argument.  In the above example, C<value> is C<'10.23'>.
 C<currency> converts a value with a currency code suffix to another currency
 using the current exchange rate as determined by the
 Finance::Quote::CurrencyRates method or methods configured for the quoter $q.
-When called as a class method, only Finance::Quote::AlphaVantage is used, which
-requires an API key. See the introduction for information on configuring
+When called as a class method, Finance::Quote::AlphaVantage is the default,
+which requires an API key. See the introduction for information on configuring
 currency rate conversions and see Finance::Quote::CurrencyRates::AlphaVantage
 for information about the API key.
 
@@ -1670,6 +1678,7 @@ http://www.gnucash.org/
 =head1 SEE ALSO
 
   Finance::Quote::CurrencyRates::AlphaVantage,
+  Finance::Quote::CurrencyRates::CurrencyFreaks,
   Finance::Quote::CurrencyRates::ECB,
   Finance::Quote::CurrencyRates::Fixer,
   Finance::Quote::CurrencyRates::OpenExchange,
@@ -1678,6 +1687,7 @@ http://www.gnucash.org/
   Finance::Quote::ASEGR,
   Finance::Quote::ASX,
   Finance::Quote::Bloomberg,
+  Finance::Quote::BorsaItaliana,
   Finance::Quote::BSEIndia,
   Finance::Quote::Bourso,
   Finance::Quote::BVB,
@@ -1687,9 +1697,11 @@ http://www.gnucash.org/
   Finance::Quote::Currencies,
   Finance::Quote::DWS,
   Finance::Quote::Deka,
-  Finance::Quote::FTfunds,
+  Finance::Quote::FinanceAPI,
   Finance::Quote::Finanzpartner,
   Finance::Quote::Fondsweb,
+  Finance::Quote::Fool,
+  Finance::Quote::FTfunds,
   Finance::Quote::GoldMoney,
   Finance::Quote::GoogleWeb,
   Finance::Quote::HU,
@@ -1706,6 +1718,8 @@ http://www.gnucash.org/
   Finance::Quote::Oslobors,
   Finance::Quote::SEB,
   Finance::Quote::SIX,
+  Finance::Quote::StockData,
+  Finance::Quote::Stooq,
   Finance::Quote::TSP,
   Finance::Quote::TMX,
   Finance::Quote::Tiaacref,
