@@ -30,7 +30,7 @@ use LWP::UserAgent;
 use Web::Scraper;
 use String::Util qw(trim);
 
-our $VERSION = '1.61'; # VERSION
+our $VERSION = '1.63'; # VERSION
 
 sub methods { 
   return (dutch => \&aex,
@@ -90,7 +90,7 @@ sub aex {
         }
 
         # die "Failed to find isin" unless $url->as_string =~ m|/([A-Za-z0-9]{12}-[A-Za-z]+)/|;
-        unless (defined($url) && $url->as_string =~ m|/([A-Za-z0-9]{12}-[A-Za-z]+)/|) {
+        unless (defined($url) && $url->as_string =~ m|(/[A-Za-z0-9]{12}-[A-Za-z]+\b)|) {
             $info{$symbol, 'success'} = 0;
             $info{$symbol, 'errormsg'} = 'Cannot find ISIN for ' . $symbol;
             next;
