@@ -19,12 +19,12 @@ package Finance::Quote::BSEIndia;
 
 use strict;
 use POSIX qw(strftime);
-use IO::Uncompress::Unzip qw(unzip $UnzipError);
+#use IO::Uncompress::Unzip qw(unzip $UnzipError);
 
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments', '###';
 
-our $VERSION = '1.62'; # VERSION
+our $VERSION = '1.63'; # VERSION
 
 use vars qw($BSE_URL);
 $BSE_URL = "https://www.bseindia.com";
@@ -48,19 +48,21 @@ sub bseindia {
     my (%info, $errormsg, $fh, $ua, $url, $reply);
 	my $output;
 	my @array;
-	
+	my $meuradate;
+
     $ua = $quoter->user_agent;
     # Set the ua to be blank. Server blocks default useragent.
     $ua->agent('');
 
     # Try to fetch last 10 days
     for (my ($days, $now) = (0, time()); $days < 10; $days++) {
-        # Ex: https://www.bseindia.com/download/BhavCopy/Equity/BSE_EQ_BHAVCOPY_12112023.ZIP
+        # Ex: https://www.bseindia.com/download/BhavCopy/Equity/BhavCopy_BSE_CM_0_0_0_20240718_F_0000.CSV
         my @lt = localtime($now - $days*24*60*60);
         my ($date, $url, $req, $output);	# added $req, $output for fileless
         
-        $date = strftime "%d%m%Y", @lt;
-        $url = sprintf("https://www.bseindia.com/download/BhavCopy/Equity/BSE_EQ_BHAVCOPY_%s.ZIP", $date);
+        $date = strftime "%Y%m%d", @lt;
+        $url = sprintf("https://www.bseindia.com/download/BhavCopy/Equity/BhavCopy_BSE_CM_0_0_0_%s_F_0000.CSV", $date);
+
         $req = HTTP::Request->new(GET => $url);     #added for fileless
         $reply = $ua->request($req);
         #print "$url", $reply->is_success, $reply->status_line, "\n"; #DEBUG
@@ -75,11 +77,9 @@ sub bseindia {
 
     if (!$errormsg) {
 		#Does not use temp files. Fileless into variable $output
-        if (! unzip \$reply->content => \$output) {
-            $errormsg = "Unzip error : $UnzipError";
-        } else {
-			@array = split("\n", $output);
-		}
+		#There is no zip file anymore
+		#@array = split("\n", $output);
+		@array = split("\n", $reply->content);
     }
 
     if ($errormsg) {
@@ -99,8 +99,7 @@ sub bseindia {
     my $csvhead;
     my @headhash;
 
-    # SC_CODE,SC_NAME,SC_GROUP,SC_TYPE,OPEN,HIGH,LOW,CLOSE,LAST,PREVCLOSE,NO_TRADES,NO_OF_SHRS,NET_TURNOV,TDCLOINDI,ISIN_CODE,TRADING_DATE,FILLER2,FILLER3
-    # ISIN,TckrSymb,FinInstrmId,FinInstrmNm,SctySrs,OpnPric,HghPric,LwPric,ClsPric,LastPric,PrvsClsgPric,TtlTradgVol,TtlTrfVal,TradDt,TtlNbOfTxsExctd,FinInstrmTp,OffclCorpActnEvtId,RptgDt,TradRegnOrgn,MktTpandId,InstrmId,InstrmNm,FftyTwWkHgh,FftyTwWkLw,UnitOfMeasr,SttlmPric,AvrgPric,Ccy,Rsvd01,Rsvd02,Rsvd03,Rsvd04
+    # TradDt,BizDt,Sgmt,Src,FinInstrmTp,FinInstrmId,ISIN,TckrSymb,SctySrs,XpryDt,FininstrmActlXpryDt,StrkPric,OptnTp,FinInstrmNm,OpnPric,HghPric,LwPric,ClsPric,LastPric,PrvsClsgPric,UndrlygPric,SttlmPric,OpnIntrst,ChngInOpnIntrst,TtlTradgVol,TtlTrfVal,TtlNbOfTxsExctd,SsnId,NewBrdLotQty,Rmks,Rsvd1,Rsvd2,Rsvd3,Rsvd4
     
     $csvhead = $array[0];
 
@@ -129,7 +128,7 @@ sub bseindia {
 		$info{$symbol, 'open'} = $datahash{"OpnPric"};
 		$info{$symbol, 'prevclose'} = $datahash{"PrvsClsgPric"};
 		$info{$symbol, 'name'} = $datahash{"FinInstrmNm"};
-		$quoter->store_date(\%info, $symbol, {eurodate => $datahash{"TradDt"}});
+		$quoter->store_date(\%info, $symbol, {isodate => $datahash{"TradDt"}});
 		$info{$symbol, 'method'} = 'bseindia';
 		$info{$symbol, 'currency'} = 'INR';
 		$info{$symbol, 'exchange'} = 'BSE';
