@@ -30,7 +30,7 @@ use if DEBUG, 'Smart::Comments';
 
 use JSON;
 
-our $VERSION = '1.68_01'; # TRIAL VERSION
+our $VERSION = '1.63'; # VERSION
 
 sub parameters {
   return ('API_KEY');
@@ -118,9 +118,7 @@ sub multipliers
     return ($b, $a);
   }
 
-  return ($json_data->{'rates'}->{${from}}, $json_data->{'rates'}->{${to}});
-
-  # return (1.0, $rate);
+  return (1.0, $rate);
 }
 
 
