@@ -33,7 +33,7 @@ use JSON qw( decode_json );
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments', '###';
 
-our $VERSION = '1.68_01'; # TRIAL VERSION
+our $VERSION = '1.63'; # VERSION
 
 my $FINANCEAPI_URL = 'https://yfapi.net/v6/finance/quote?region=US&lang=en&symbols=';
 
@@ -96,7 +96,7 @@ sub financeapi {
     my $code    = $reply->code;
     my $desc    = HTTP::Status::status_message($code);
     my $headers = $reply->headers_as_string;
-    my $body    = $reply->content;
+    my $body    = decode('UTF-8', $reply->content);
 
     ### Body: $body
 
@@ -122,15 +122,6 @@ sub financeapi {
         next;
       }
 
-      # JSON Result Array is sometimes empty
-      my $json_data_count = scalar @{ $quote->{'quoteResponse'}{'result'} };
-      if ( $json_data_count < 1 ) {
-        $info{ $stock, "success" } = 0;
-        $info{ $stock, "errormsg" } =
-          "Error retrieving quote for $stock - no listing for this name found. Please check symbol and the two letter extension (if any)";
-        next;
-      }
-
       $name     = $quote->{'quoteResponse'}{'result'}[0]{'longName'};
       $open     = $quote->{'quoteResponse'}{'result'}[0]{'regularMarketOpen'};
       $high     = $quote->{'quoteResponse'}{'result'}[0]{'regularMarketDayHigh'};
