@@ -1,4 +1,5 @@
 #!/usr/bin/perl -w
+# vi: set ts=4 sw=4 noai ic showmode showmatch:  
 
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -23,20 +24,30 @@ use warnings;
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments';
 
+use Encode;
+use JSON qw( decode_json );
 use LWP::UserAgent;
 use Web::Scraper;
 use String::Util qw(trim);
 
-our $VERSION = '1.62'; # VERSION
+our $VERSION = '1.63'; # VERSION
 
-our @labels = qw/last isin name currency date isodate/;
+our $DISPLAY    = 'NZX - New Zealand Exchange';
+our @LABELS     = qw/last isin name currency date isodate/;
+our $METHODHASH = {subroutine => \&nzx, 
+                   display => $DISPLAY, 
+                   labels => \@LABELS};
 
-sub labels {
-  return ( nzx => \@labels );
+sub methodinfo {
+    return ( 
+        nzx => $METHODHASH,
+    );
 }
 
+sub labels { my %m = methodinfo(); return map {$_ => [@{$m{$_}{labels}}] } keys %m; }
+
 sub methods {
-  return ( nzx => \&nzx );
+  my %m = methodinfo(); return map {$_ => $m{$_}{subroutine} } keys %m;
 }
 
 sub nzx {
@@ -50,26 +61,41 @@ sub nzx {
         my $url   = "https://www.nzx.com/instruments/$symbol";
         my $reply = $ua->get($url);
 
+        # JSON inside script id="__NEXT_DATA__" type="application/json" crossorigin="">
         my $widget = scraper {
-          process '/html/body/section/div[2]/div/section[1]/div/div[1]/h1', 'last' => ['TEXT', sub{trim($_)}];
-          process '/html/body/section/div[2]/div/section[1]/div/div[2]/table/tbody/tr[5]/td[2]', 'isin' => ['TEXT', sub{trim($_)}];
-          process '/html/body/section/div[2]/div/section[1]/div/div[2]/table/tbody/tr[1]/td[2]', 'name' => ['TEXT', sub{trim($_)}]; 
-          process '/html/body/section/div[2]/div/div[2]/span', 'when' => ['TEXT', sub{trim($_)}]; 
+            process '//script[contains(@id, "__NEXT_DATA__")]/text()', "script" => 'TEXT';
         };
 
-        my $result = $widget->scrape($reply);
+        my $result = $widget->scrape($reply->decoded_content);
+        #my $result = $widget->scrape($reply->content);
         ### RESULT : $result
+        ### [<now>] Result->script: $result->{script}
 
-        die "Failed to find $symbol" unless exists $result->{last};
-     
+        my $json = encode_utf8($result->{script});
+        my $json_data;
+        eval {$json_data = JSON::decode_json($json)};
+        if ($@) {
+            $info{ $symbol, 'success' } = 0;
+            $info{ $symbol, 'errormsg' } = $@;
+        }
+        ### [<now>] JSON Data: $json_data
+
+        unless ($json_data->{'props'}{'pageProps'}{'overview'}{'code'}
+        eq $symbol) {
+            $info{$symbol, 'success'} = 0;
+            $info{$symbol, 'errormsg'} = 'Symbol not found';
+            next;
+        }
         
         $info{$symbol, 'success'}  = 1;
         $info{$symbol, 'currency'} = 'NZD';
-        $info{$symbol, 'last'}    = $1 if $result->{last} =~ /([0-9.]+)/;
-        $info{$symbol, 'isin'}    = $result->{isin};
-        $info{$symbol, 'name'}    = $result->{name};
+        $info{$symbol, 'symbol'}  = $symbol;
+        $info{$symbol, 'last'}    = $json_data->{'props'}{'pageProps'}{'overview'}{'priceAmount'};
+        $info{$symbol, 'isin'}    = $json_data->{'props'}{'pageProps'}{'overview'}{'ISIN'};
+        $info{$symbol, 'name'}    = $json_data->{'props'}{'pageProps'}{'overview'}{'name'};
       
-        $quoter->store_date(\%info, $symbol, {eurodate => $1}) if $result->{when} =~ m|([0-9]{1,2}/[0-9]{1,2}/[0-9]{4})|;
+        my $closePriceDate = $json_data->{'props'}{'pageProps'}{'overview'}{'closePriceDate'};
+        $quoter->store_date(\%info, $symbol, {isodate => $closePriceDate});
       };
       
       if ($@) {
@@ -86,6 +112,8 @@ sub nzx {
 
 1;
 
+__END__
+
 =head1 NAME
 
 Finance::Quote::NZX - Obtain quotes from New Zealand's
@@ -97,11 +125,11 @@ Exchange www.nzx.com
 
     $q = Finance::Quote->new;
 
-    %stockinfo = $q->fetch('nzx','TPW');
+    %stockinfo = $q->fetch('nzx','MNW');
 
 =head1 DESCRIPTION
 
-This module obtains information fromwww.nzx.com.
+This module obtains information from L<NZX|https://www.nzx.com/>.
 
 =head1 LABELS RETURNED
 
